﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;

namespace ELTE.Forms.VectorDrawing
{
    /// <summary>
    /// Vektoros alakzatfajta felsorolási típusa.
    /// </summary>
    public enum ShapeType { Rectangle, Ellipse, Triangle }

    /// <summary>
    /// Vektoros alakzat osztálya
    /// </summary>
    public class Shape
    {
        private ShapeType _Type; // típus
        private Rectangle _Location; // befoglaló téglalap, amely tartalmazza az elhelyezkedést és a méretet

        /// <summary>
        /// Alakzat lérehozása.
        /// </summary>
        /// <param name="type">Alakzat típusa.</param>
        /// <param name="x">Alakzat vízszintes pozíciója.</param>
        /// <param name="y">Alakzat függőleges pozíciója.</param>
        /// <param name="width">Alakzat szélessége.</param>
        /// <param name="height">Alakzat magassága.</param>
        public Shape(ShapeType type, Int32 x, Int32 y, Int32 width, Int32 height)
        {
            _Type = type;
            _Location = new Rectangle(x, y, width, height);
        }

        /// <summary>
        /// Alakzat kijazolása.
        /// </summary>
        /// <param name="graphics">Rajzobjektum.</param>
        public void Draw(Graphics graphics)
        {
            switch (_Type)
            {
                case ShapeType.Ellipse:
                    graphics.FillEllipse(Brushes.Red, _Location); // alakzat kitöltése
                    graphics.DrawEllipse(Pens.DarkRed, _Location); // alakzat határoló vonala
                    break;
                case ShapeType.Rectangle:
                    graphics.FillRectangle(Brushes.LightGreen, _Location);
                    graphics.DrawRectangle(Pens.DarkGreen, _Location);
                    break;
                case ShapeType.Triangle:

                    Point[] points = new Point[3]; // a háromszöget poligonként rajzoljuk, pontok segítségével
                    points[0] = new Point(_Location.X + _Location.Width / 2, _Location.Y);
                    points[1] = new Point(_Location.X, _Location.Y + _Location.Height);
                    points[2] = new Point(_Location.X + _Location.Width, _Location.Y + _Location.Height);

                    graphics.FillPolygon(Brushes.Yellow, points);
                    graphics.DrawPolygon(Pens.Orange, points);
                    break;
            }
        }
    }
}
